==> auto-ui-2.1.25.tgz: package/es/tabs/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var TabsItem = function (props) {
    var active = props.active, value = props.value, className = props.className, onClick = props.onClick, children = props.children, otherProps = __rest(props, ["active", "value", "className", "onClick", "children"]);
    var composeClassName = cn('x-tabs__item', {
        'x-tabs--active': !!active,
    }, className);
    var onAClick = function () {
        onClick(value);
    };
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onAClick }), children));
};
var Tabs = function (props) {
    var className = props.className, children = props.children, active = props.active, onClick = props.onClick, otherProps = __rest(props, ["className", "children", "active", "onClick"]);
    var composeClassName = cn('x-tabs', className);
    var activeOffset = -2;
    var composeChildren = [];
    if (Array.isArray(children)) {
        composeChildren.push.apply(composeChildren, children);
    }
    else {
        composeChildren.push(children);
    }
    composeChildren = composeChildren.map(function (res, index) {
        var act = props.hasOwnProperty('active') && res.props.value === props.active;
        if (act) {
            activeOffset = index;
        }
        return React.cloneElement(res, {
            active: act,
            key: index,
            value: res.props.value,
            onClick: props.onClick,
            children: res.props.children,
        });
    });
    var _a = React.useState('x-tabs__line'), cls = _a[0], setCls = _a[1];
    var _b = React.useState(true), first = _b[0], setFirst = _b[1];
    React.useEffect(function () {
        if (!first) {
            setCls('x-tabs__line x-tabs__line--ani');
        }
        else {
            setFirst(false);
        }
    }, [activeOffset]);
    var onTransEnd = function () {
        setCls('x-tabs__line');
    };
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("sub", { className: cls, style: {
                width: 100 / composeChildren.length + "%",
                WebkitTransform: "translate(" + activeOffset * 100 + "%, 0)",
            }, onTransitionEnd: onTransEnd }),
        composeChildren));
};
Tabs.Item = TabsItem;
export default Tabs;

==> auto-ui-2.1.26.tgz: package/es/tabs/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style.scss';
var TabsItem = function (props) {
    var active = props.active, value = props.value, className = props.className, onClick = props.onClick, children = props.children, otherProps = __rest(props, ["active", "value", "className", "onClick", "children"]);
    var composeClassName = cn('x-tabs__item', {
        'x-tabs--active': !!active,
    }, className);
    var onAClick = function () {
        onClick(value);
    };
    return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onAClick }), children));
};
var Tabs = function (props) {
    var className = props.className, children = props.children, active = props.active, onClick = props.onClick, otherProps = __rest(props, ["className", "children", "active", "onClick"]);
    var composeClassName = cn('x-tabs', className);
    var activeOffset = -2;
    var composeChildren = [];
    if (Array.isArray(children)) {
        composeChildren.push.apply(composeChildren, children);
    }
    else {
        composeChildren.push(children);
    }
    composeChildren = composeChildren.map(function (res, index) {
        var act = props.hasOwnProperty('active') && res.props.value === props.active;
        if (act) {
            activeOffset = index;
        }
        return React.cloneElement(res, {
            active: act,
            key: index,
            value: res.props.value,
            onClick: props.onClick,
            children: res.props.children,
        });
    });
    var _a = React.useState('x-tabs__line'), cls = _a[0], setCls = _a[1];
    var _b = React.useState(true), first = _b[0], setFirst = _b[1];
    React.useEffect(function () {
        if (!first) {
            setCls('x-tabs__line x-tabs__line--ani');
        }
        else {
            setFirst(false);
        }
    }, [activeOffset]);
    var onTransEnd = function () {
        setCls('x-tabs__line');
    };
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("sub", { className: cls, style: {
                width: 100 / composeChildren.length + "%",
                WebkitTransform: "translate(" + activeOffset * 100 + "%, 0)",
            }, onTransitionEnd: onTransEnd }),
        composeChildren));
};
Tabs.Item = TabsItem;
export default Tabs;
